Name:           derby
Version:        10.10.2.0
%define subrel  1
Release:        %mkrel 1
Summary:        Relational database implemented entirely in Java
Group:          Development/Java
License:        ASL 2.0
URL:            http://db.apache.org/derby/
Source0:        http://apache.mirror.anlx.net/db/derby/db-%{name}-%{version}/db-%{name}-%{version}-src.tar.gz
Source1:        derby-script
Source2:        derby.service

# https://issues.apache.org/jira/browse/DERBY-5125
Patch1:         derby-javacc5.patch
# https://bugzilla.redhat.com/show_bug.cgi?id=830661
Patch2:         derby-net.patch
# PATCH-FIX-UPSTREAM bnc#1002763
Patch3:         derby-CVE-2015-1832.patch

BuildRequires:  java-devel >= 1.6
BuildRequires:  javapackages-local
BuildRequires:  servlet3
BuildRequires:  jakarta-oro
BuildRequires:  javacc
BuildRequires:  junit
BuildRequires:  xalan-j2
BuildRequires:  ant
BuildRequires:  systemd-units
BuildRequires:  maven-artifact-manager

Requires(pre):  shadow-utils
Requires(preun): systemd-units
Requires(post): systemd-units

BuildArch:      noarch

%description
Apache Derby, an Apache DB sub-project, is a relational database implemented
entirely in Java. Some key advantages include a small footprint, conformance
to Java, JDBC, and SQL standards and embedded JDBC driver.

#--------------------------------------------------------

%package        javadoc
Summary:        API documentation for derby
Group:          Documentation

%description    javadoc
This package contains the API documentation for %{name}.

#--------------------------------------------------------
%prep
%setup -q -c

find -name '*.jar' -delete
find -name '*.class' -delete

pushd db-%{name}-%{version}-src
rm java/engine/org/apache/derby/impl/sql/compile/Token.java
%patch1 -p0
%patch2 -p0
%patch3 -p1
popd

%build
cd db-%{name}-%{version}-src

# tools/ant/properties/extrapath.properties
ln -sf $(build-classpath javacc) tools/java/javacc.jar
ln -sf $(build-classpath servlet25) \
        tools/java/geronimo-spec-servlet-2.4-rc4.jar
ln -sf $(build-classpath xalan-j2) tools/java/xalan.jar
ln -sf $(build-classpath xalan-j2-serializer) tools/java/serializer.jar
ln -sf $(build-classpath oro) tools/java/jakarta-oro-2.0.8.jar
ln -sf $(build-classpath junit) tools/java/junit.jar

# Using generics
find -name build.xml |xargs sed '
        s/target="1.4"/target="1.6"/
        s/source="1.4"/source="1.6"/
        /Class-Path/d
' -i

# Fire
%ant buildsource buildjars javadoc

# Generate maven poms
find maven2 -name pom.xml | xargs sed -i -e 's|ALPHA_VERSION|%{version}|'

# Request maven installation
%mvn_artifact maven2/pom.xml
for p in engine net client tools \
    derbyLocale_cs derbyLocale_de_DE derbyLocale_es derbyLocale_fr derbyLocale_hu \
    derbyLocale_it derbyLocale_ja_JP derbyLocale_ko_KR derbyLocale_pl derbyLocale_pt_BR \
    derbyLocale_ru derbyLocale_zh_CN derbyLocale_zh_TW ; do
  d=derby${p#derby}
  %mvn_artifact maven2/${p}/pom.xml jars/sane/${d%engine}.jar
done

%install
cd db-%{name}-%{version}-src

%mvn_install

# Wrapper scripts
mkdir -p %{buildroot}%{_bindir}
install -p -m 0755 %{SOURCE1} %{buildroot}%{_bindir}/%{name}-ij

for P in sysinfo NetworkServerControl startNetworkServer stopNetworkServer
do
        ln %{buildroot}%{_bindir}/%{name}-ij \
                %{buildroot}%{_bindir}/%{name}-$P
done

# Systemd unit
mkdir -p %{buildroot}%{_unitdir}
install -p -m 0644 %{SOURCE2} \
        %{buildroot}%{_unitdir}/%{name}.service

# Derby home dir
install -dm 0755 %{buildroot}%{_localstatedir}/lib/%{name}
install -dm 0755 %{buildroot}%{_sharedstatedir}/%{name}

# Javadoc
install -d -m 0755 %{buildroot}%{_javadocdir}/%{name}
cp -pr javadoc/* %{buildroot}%{_javadocdir}/%{name}

%pre
getent group derby >/dev/null || groupadd -r derby
getent passwd derby >/dev/null || \
    useradd -r -g derby -d /var/lib/derby -s /sbin/nologin \
    -c "Apache Derby service account" derby
exit 0

%preun
%_preun_service %{name}

%post
%_post_service %{name}

%files -f  db-%{name}-%{version}-src/.mfiles
%{_bindir}/*
%dir %{_javadir}/%{name}
%doc db-%{name}-%{version}-src/LICENSE
%doc db-%{name}-%{version}-src/NOTICE
%doc db-%{name}-%{version}-src/published_api_overview.html
%doc db-%{name}-%{version}-src/RELEASE-NOTES.html
%doc db-%{name}-%{version}-src/README
%{_unitdir}/%{name}.service
%attr(755,derby,derby) %{_sharedstatedir}/%{name}
%attr(755,derby,derby) %{_localstatedir}/lib/%{name}

%files javadoc
%doc db-%{name}-%{version}-src/LICENSE
%doc db-%{name}-%{version}-src/NOTICE
%{_javadocdir}/%{name}


%changelog
* Mon Oct 24 2016 daviddavid <daviddavid> 10.10.2.0-1.1.mga5
+ Revision: 1063416
- add openSUSE patch to fix CVE-2015-1832 (mga#19590)

* Tue Dec 30 2014 daviddavid <daviddavid> 10.10.2.0-1.mga5
+ Revision: 807438
- Sync with fc21 (update to 10.10.2.0)

  + umeabot <umeabot>
    - Second Mageia 5 Mass Rebuild
    - Mageia 5 Mass Rebuild

* Fri Jan 03 2014 dmorgan <dmorgan> 10.9.1.0-2.mga4
+ Revision: 564020
- Rebuild against fixed owasp-esapi-java

* Thu Jan 02 2014 dmorgan <dmorgan> 10.9.1.0-1.mga4
+ Revision: 563945
- New version

  + umeabot <umeabot>
    - Mageia 4 Mass Rebuild
    - Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Sep 20 2012 dmorgan <dmorgan> 10.6.2.1-1.mga3
+ Revision: 296308
- Sync with fedora spec file

* Thu Dec 15 2011 gil <gil> 10.6.2.1-1.mga2
+ Revision: 181761
- update to 10.6.2.1

* Thu Apr 28 2011 dmorgan <dmorgan> 10.6.1.0-7.mga1
+ Revision: 92433
- Rebuild after bootstrapping
- imported package derby


* Fri Feb 25 2011 Lubomir Rintel <lkundrak@v3.sk> - 10.6.1.0-6
- Fix startup script (Thomas Meyer, #668828)

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 10.6.1.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Fri Nov 26 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 10.6.1.0-4
- Fix pom filenames (Resolves rhbz#655794)

* Tue Jul 27 2010 Lubomir Rintel <lkundrak@v3.sk> - 10.6.1.0-3
- Fix buildrequires

* Tue Jul 27 2010 Lubomir Rintel <lkundrak@v3.sk> - 10.6.1.0-2
- Add tool launchers
- Add POMs

* Mon Jun 28 2010 Lubomir Rintel <lkundrak@v3.sk> - 10.6.1.0-1
- Initial packaging
